@@ -17,9 +17,10 @@ from .settings import Config
 
 def reformat_file(config: Config, this_file: Path) -> dict:
     """Reformat html file."""
-    rawcode = this_file.read_text(encoding="utf8")
+    rawcode = this_file.read_bytes().decode("utf8")
 
-    compressed = compress_html(rawcode, config)
+    # naturalize the line breaks
+    compressed = compress_html(("\n").join(rawcode.splitlines()), config)
 
     expanded = expand_html(compressed, config)
 
@@ -33,9 +34,14 @@ def reformat_file(config: Config, this_file: Path) -> dict:
     if config.format_js:
         beautified_code = format_js(beautified_code, config)
 
+    # preserve original line endings
+    line_ending = rawcode.find("\n")
+    if line_ending > -1 and rawcode[max(line_ending - 1, 0)] == "\r":
+        # convert \r?\n to \r\n
+        beautified_code = beautified_code.replace("\r", "").replace("\n", "\r\n")
+
     if config.check is not True or config.stdin is True:
-        # update the file
-        this_file.write_text(beautified_code, encoding="utf8")
+        this_file.write_bytes(beautified_code.encode("utf8"))
 
     out = {
         str(this_file): list(
